@@ -1,23 +1,11 @@
 from terra_sdk.core import Coin, Dec
 
-from ._base import BaseAPI
+from ._base import BaseAsyncAPI, sync_bind
+
+__all__ = ["AsyncMarketAPI", "MarketAPI"]
 
 
-class AsyncMarketAPI(BaseAPI):
-    def swap_rate(self, offer_coin: Coin, ask_denom: str) -> Coin:
-        params = {"offer_coin": str(offer_coin), "ask_denom": ask_denom}
-        res = self._c._get("/market/swap", params)
-        return Coin.from_data(res)
-
-    def terra_pool_delta(self) -> Dec:
-        res = self._c._get("/market/terra_pool_delta")
-        return Dec(res)
-
-    def parameters(self) -> dict:
-        return self._c._get("/market/parameters")
-
-
-class MarketAPI(BaseAPI):
+class AsyncMarketAPI(BaseAsyncAPI):
     def swap_rate(self, offer_coin: Coin, ask_denom: str) -> Coin:
         """Simulates a swap given an amount offered and a target denom.
 
@@ -48,3 +36,23 @@ class MarketAPI(BaseAPI):
             dict: Market module parameters
         """
         return self._c._get("/market/parameters")
+
+
+class MarketAPI(AsyncMarketAPI):
+    @sync_bind(AsyncMarketAPI.swap_rate)
+    def swap_rate(self, offer_coin: Coin, ask_denom: str) -> Coin:
+        pass
+
+    swap_rate.__doc__ = AsyncMarketAPI.swap_rate.__doc__
+
+    @sync_bind(AsyncMarketAPI.terra_pool_delta)
+    def terra_pool_delta(self) -> Dec:
+        pass
+
+    terra_pool_delta.__doc__ = AsyncMarketAPI.terra_pool_delta.__doc__
+
+    @sync_bind(AsyncMarketAPI.parameters)
+    def parameters(self) -> dict:
+        pass
+
+    parameters.__doc__ = AsyncMarketAPI.parameters.__doc__
