@@ -1,12 +1,14 @@
 from __future__ import annotations
 
-from typing import List, Optional
+from typing import List, Optional, Union
 
 import attr
 
 from terra_sdk.core.auth import TxLog, parse_tx_logs
 from terra_sdk.util.json import JSONSerializable
 
+__all__ = ["BlockTxBroadcastResult", "SyncTxBroadcastResult", "AsyncTxBroadcastResult"]
+
 
 @attr.s
 class BlockTxBroadcastResult(JSONSerializable):
@@ -20,6 +22,9 @@ class BlockTxBroadcastResult(JSONSerializable):
     code: Optional[int] = attr.ib(default=None)
     codespace: Optional[str] = attr.ib(default=None)
 
+    def is_tx_error(self) -> bool:
+        return is_tx_error(self)
+
 
 @attr.s
 class SyncTxBroadcastResult(JSONSerializable):
@@ -30,9 +35,16 @@ class SyncTxBroadcastResult(JSONSerializable):
     code: Optional[int] = attr.ib(default=None)
     codespace: Optional[str] = attr.ib(default=None)
 
+    def is_tx_error(self) -> bool:
+        return is_tx_error(self)
+
 
 @attr.s
 class AsyncTxBroadcastResult(JSONSerializable):
 
     height: int = attr.ib(converter=int)
     txhash: str = attr.ib()
+
+
+def is_tx_error(result: Union[BlockTxBroadcastResult, SyncTxBroadcastResult]):
+    return result.code is not None
