@@ -11,11 +11,16 @@ LUNA_COIN_TYPE = 330
 
 
 class MnemonicKey(RawKey):
+    """Key implementation based on BIP39 mnemonic."""
 
     mnemonic: str
     account: int
     index: int
-    coin_type = int
+    coin_type: int
+
+    @property
+    def hd_path(self):
+        return f"m/44'/{self.coin_type}'/{self.account}'/0/{self.index}"
 
     def __init__(
         self,
@@ -24,6 +29,14 @@ class MnemonicKey(RawKey):
         index: int = 0,
         coin_type: int = LUNA_COIN_TYPE,
     ):
+        """Creates a new MnemonicKey.
+
+        Args:
+            mnemonic (str, optional): [description]. Defaults to None.
+            account (int, optional): [description]. Defaults to 0.
+            index (int, optional): [description]. Defaults to 0.
+            coin_type (int, optional): [description]. Defaults to LUNA_COIN_TYPE.
+        """
         if mnemonic is None:
             mnemonic = Mnemonic("english").generate(256)
         seed = Mnemonic("english").to_seed(mnemonic)
